import fastapi
import pydantic

from api.router import router
from exceptions import handlers as exc_handlers, http as http_exc
from db.conf import init_db


def setup():
    app = fastapi.FastAPI()
    app.include_router(router)

    app.exception_handler(pydantic.ValidationError)(exc_handlers.query_params_exc_handler)
    app.exception_handler(http_exc.BaseHTTPException)(exc_handlers.request_exc_handler)
    app.exception_handler(500)(exc_handlers.internal_exc_handler)

    return app


app = setup()

init_db(app)

if __name__ == '__main__':
    import uvicorn

    uvicorn.run('main:app', host='0.0.0.0', port=8000, reload=True)
